==> cmsmadesimple-1.6.6.tgz: cms/modules/FileManager/lang/ext/lt_LT.php <==
<?php
$lang['friendlyname'] = 'Bylų valdymas/siuntimas';
$lang['permission'] = 'Naudojimasis Bylų valdymo moduliu';
$lang['permissionadvanced'] = 'Sudėtingesnis naudojimasis Bylų valdymo moduliu';
$lang['moddescription'] = 'Bylų ir direktorijų tvarkymas, bylu atsiuntimas';
$lang['installed'] = 'FileManager versija %s įdiegta';
$lang['postinstall'] = 'FileManager modulis įdiegtas';
$lang['uninstalled'] = 'FileManager modulis pa&scaron;alintas';
$lang['really_uninstall'] = 'Ar jūs tikrai norite pa&scaron;alinti FileManager modulį ?';
$lang['upgraded'] = 'Atnaujinta į versija %s.';
$lang['fileview'] = 'Bylų peržiūra';
$lang['switchtofileview'] = 'Perjungti į bylų peržiūra';
$lang['settings'] = 'Nustatymai';
$lang['savesettings'] = 'I&scaron;saugoti nustatymus';
$lang['filename'] = 'Pavadinimas';
$lang['fileinfo'] = 'Informacija ';
$lang['fileowner'] = 'Bylos savininkas';
$lang['fileperms'] = 'Leidimai';
$lang['filesize'] = 'Dydis';
$lang['filedate'] = 'Data';
$lang['actions'] = 'Veiksmai';
$lang['delete'] = '&Scaron;alinti';
$lang['notwritable'] = 'Neįra&scaron;oma';
$lang['filetoobig'] = 'perdidelis. Atsiuntimas at&scaron;auktas.';
$lang['bytes'] = 'baitai';
$lang['kb'] = ' kb';
$lang['mb'] = ' mb';
$lang['files'] = 'bylos';
$lang['bytesin'] = 'baitai';
$lang['in'] = '-';
$lang['file'] = 'bylos';
$lang['fileno'] = 'Bylos nr.';
$lang['subdirs'] = 'subdirektorijos';
$lang['subdir'] = 'subdirektorija';
$lang['and'] = 'ir';
$lang['confirmsingledelete'] = 'Ar jūs tikras tuo?';
$lang['confirmsingledirdelete'] = 'Ar jūs tikrai norite i&scaron;trinti direktoriją?';
$lang['dirtreedeletesuccess'] = 'Direktorija su visu turiniu i&scaron;trinta.';
$lang['dirtreedeletefail'] = 'Klaida trinant direktoriją. Bet turinys gali būt trinamas.
';
$lang['singlefiledeletesuccess'] = 'Byla sėkmingai i&scaron;trinta';
$lang['filedeletesuccess'] = 'sėkmingai i&scaron;trinta';
$lang['singlefiledeletefail'] = 'Klaida trinant bylą';
$lang['filedeletefail'] = 'nei&scaron;trinta dėl klaidos';
$lang['singledirdeletesuccess'] = 'Direktorija sėkmingai i&scaron;trinta';
$lang['singledirdeletefail'] = 'Klaida trinant direktorija (ar ji tusčia?)';
$lang['deleteselected'] = 'I&scaron;trinti pasirinktas bylas';
$lang['confirmselected'] = 'Ar jūs tikras tuo?';
$lang['confirmdeleteselected'] = 'Ar tikrai pažymėtos bylos turėtų būt i&scaron;trintos?';
$lang['deleteselectedcancelled'] = 'Pažymėtų bylų trynimas at&scaron;auktas';
$lang['recursetext'] = 'Recurse into subdirs';
$lang['recursenotice'] = 'Please note that for now only the permissions of the selected directory is changed.';
$lang['nofilesselected'] = 'Nepasirinkote bylų';
$lang['moveselected'] = 'Perkelti pažymėtas bylas';
$lang['copyselected'] = 'Kopijuoti pažymėtas bylas';
$lang['selecttargetdir'] = 'Pasirinkite kur perkelti/kopijuoti bylas';
$lang['movedto'] = 'perkelta į';
$lang['copiedto'] = 'nukopijuota į';
$lang['couldnotmove'] = 'neįmanoma perkelti';
$lang['couldnotcopy'] = 'neįmanoma kopijuoti';
$lang['rename'] = 'Pervadinti';
$lang['newname'] = 'Naujas pavadinimas:';
$lang['renamesuccess'] = 'Byla sėkmingai pervadinta';
$lang['renamefailure'] = 'Pervadinimas nepavyko';
$lang['renamecancelled'] = 'Pervadinimas at&scaron;auktas';
$lang['owner'] = 'Savininkas';
$lang['group'] = 'Grupė';
$lang['others'] = 'Kiti';
$lang['newpermissions'] = 'Naujas leidimas:';
$lang['setpermissions'] = 'Nustatyti leidimą';
$lang['permissionstyle'] = 'Leidimo stilius';
$lang['rwxstyle'] = 'rwx stilius';
$lang['755style'] = '755 stilius';
$lang['chmod'] = 'Pakeisti leidimus';
$lang['chmodselected'] = 'Pakeisti pažymėtų bylų leidimus';
$lang['chmodsuccess'] = 'Bylos turi naujus leidimus';
$lang['chmodfailure'] = 'Leidimų pakeitimas nepavyko';
$lang['chmodcancelled'] = 'Leidimų pakeitimas at&scaron;auktas';
$lang['dirchmodsuccess'] = 'Direktorija sėkmingai gavo naujus leidimus';
$lang['dirchmodfailure'] = 'Direktorijos leidimų pakeitimas nepavyko';
$lang['dirnotemptyconfirm'] = '&Scaron;i direktorija nėra tu&scaron;čia. Ar jūs tikrai norite i&scaron;trinti ją su visu turiniu?
';
$lang['dirtreedeletecancelled'] = 'Direktorijos trinymas at&scaron;auktas';
$lang['imsure'] = 'A&scaron; tikras';
$lang['cancel'] = 'At&scaron;aukti';
$lang['ok'] = 'OK ';
$lang['uploadnewfile'] = 'Siųsti naują (as) bylą (as):';
$lang['unpackafterupload'] = 'Bandyti i&scaron;pakuoti bylą po atsiuntimo (tik tgz ir dauguma zip archyvų)?';
$lang['uploadsuccess'] = 'sėkmingai atsiųsta';
$lang['uploadfail'] = 'nesėkmingai atsiųsta';
$lang['unpacksuccess'] = 'sėkmingai i&scaron;pakuota';
$lang['unpackfail'] = 'nepavyko dėl klaidų: ';
$lang['packfileopenfail'] = 'Neįmanoma atidaryti archyvo i&scaron;pakavimui (netinkamas formatas)';
$lang['packfilewritefail'] = 'Neįmanoma atidaryti bylų &amp;s ra&scaron;ymui';
$lang['currentpath'] = 'Dabartinis kelias:';
$lang['newdirname'] = 'Sukurti direktoriją:';
$lang['newdirsuccess'] = 'Direktorija sukurta sėkmingai';
$lang['newdirfail'] = 'Klaida kuriant direktoriją';
$lang['filedateformat'] = 'Y m d  H:m:s';
$lang['iconsize'] = 'Ikonų dydis';
$lang['smallicons'] = 'Mažos ikonos';
$lang['largeicons'] = 'Didelės ikonos';
$lang['thousanddelimiter'] = 'Tūkstančio skirtukas';
$lang['none'] = 'Nei vienas';
$lang['showthumbnails'] = 'Rodyti miniatūras';
$lang['showthumbnailshelp'] = 'Įjungus bus rodomos miniatiūros jei tokios yra ir paslepia miniatiūros bylą. I&scaron;jungus bus rodomos visos bylos. ';
$lang['uploadfilesto'] = 'Siunčiamos bylos į:';
$lang['uploadview'] = 'Siųsti bylas';
$lang['uploadboxes'] = 'Siunčiamų bylų skaičius';
$lang['nothinguploaded'] = 'Nenusiųsta';
$lang['unsupportedarchive'] = 'Netinkamas archyvo formatas';
$lang['uploadmethod'] = 'Siuntimo metodas';
$lang['uploaderstandard'] = 'Standartinis html input-method (leidžia i&scaron;pakavimą)';
$lang['uploaderpostlet'] = 'Postlet, Java-based, leidžia daug bylų pažymėjimą';
$lang['uploaderswf'] = 'Vaizdingas Flash-atsiuntėjęs';
$lang['enableadvanced'] = 'Įjungti sudėtingesnį variantą? (jei leidžiama)';
$lang['advancedhelp'] = 'Suteikia priėjimą prie visų cmsms bylų sistemą, ne tik /uploads/ (jei leidžiama)';
$lang['showhiddenfileshelp'] = 'Efektyvu tik pažangesnėj būsenoj';
$lang['showhiddenfiles'] = 'Rodyti paslėptas bylas';
$lang['settingsconfirmsingledelete'] = 'Patvirtinti trynimą vienos bylos?';
$lang['settingssaved'] = 'Nustatymai i&scaron;saugoti';
$lang['help'] = '		<h3>What does this do?</h3>
		<p>This module provides file management functions, eventually and hopefully replacing the rather aged builtin file management</p>
		<h3>How do I use it?</h3>
		<p>Select it from the content-menu from in the admin. While the old filemanager is still in there you should select the one furthest down in the menu.</p>';
$lang['changelog'] = '		<ul>
		  <li><b>Version 0.1.4</b></li>
		  <li>Fixed cancelling recursive deletion of dirs</li>

		  <li><b>Version 0.1.3</b></li>
		  <li>Fixed cancelling recursive deletion of dirs</li>
		  <li>Added Java-applet multifile upload method</li>
		  <li>Implemented deletion of multiple files</li>
		  <li>Fixed select all checkbox</li>

		  <li><b>Version 0.1.2</b></li>
		  <li>Added recursive deletion of dirs</li>

		  <li><b>Version 0.1.1</b></li>
		  <li>Added support for multiple uploads, and support for unpacking tar.gz-files</li>
		  <li>Rewrote to use more of the module-api-functions</li>
		  <li><b>Version 0.1.0</b></li>
		  <li>First version which work properly and equals the builtin filemanager which is intends to render obsolete</li>
		</ul>';
$lang['utma'] = '156861353.434555129.1206704373.1212477313.1212497022.37';
$lang['utmz'] = '156861353.1212140966.35.21.utmccn=(referral)|utmcsr=localhost|utmcct=/cmsmadesimple125/admin/moduleinterface.php|utmcmd=referral';
$lang['utmc'] = '156861353';
$lang['utmb'] = '156861353';
?>

==> cmsmadesimple-1.9.4p3.tgz: cms/modules/FileManager/lang/ext/lt_LT.php <==
<?php
$lang['friendlyname'] = 'Bylų valdymas/siuntimas';
$lang['permission'] = 'Naudojimasis Bylų valdymo moduliu';
$lang['permissionadvanced'] = 'Sudėtingesnis naudojimasis Bylų valdymo moduliu';
$lang['moddescription'] = 'Bylų ir direktorijų tvarkymas, bylu atsiuntimas';
$lang['installed'] = 'FileManager versija %s įdiegta';
$lang['postinstall'] = 'FileManager modulis įdiegtas';
$lang['uninstalled'] = 'FileManager modulis pa&scaron;alintas';
$lang['really_uninstall'] = 'Ar jūs tikrai norite pa&scaron;alinti FileManager modulį ?';
$lang['upgraded'] = 'Atnaujinta į versija %s.';
$lang['fileview'] = 'Bylų peržiūra';
$lang['switchtofileview'] = 'Perjungti į bylų peržiūra';
$lang['settings'] = 'Nustatymai';
$lang['savesettings'] = 'I&scaron;saugoti nustatymus';
$lang['filename'] = 'Pavadinimas';
$lang['fileinfo'] = 'Informacija ';
$lang['fileowner'] = 'Bylos savininkas';
$lang['fileperms'] = 'Leidimai';
$lang['filesize'] = 'Dydis';
$lang['filedate'] = 'Data';
$lang['actions'] = 'Veiksmai';
$lang['delete'] = '&Scaron;alinti';
$lang['notwritable'] = 'Neįra&scaron;oma';
$lang['filetoobig'] = 'perdidelis. Atsiuntimas at&scaron;auktas.';
$lang['unknown'] = 'Unknown';
$lang['fileoutsideuploads'] = 'You are not allowed to modify files outside the uploads-dir! (That requires the Advanced File Management permission)';
$lang['writable'] = 'Writable';
$lang['writeprotected'] = 'Write protected';
$lang['bytes'] = 'baitai';
$lang['kb'] = ' kb';
$lang['mb'] = ' mb';
$lang['files'] = 'bylos';
$lang['bytesin'] = 'baitai';
$lang['in'] = '-';
$lang['file'] = 'bylos';
$lang['fileno'] = 'Bylos nr.';
$lang['subdirs'] = 'subdirektorijos';
$lang['subdir'] = 'subdirektorija';
$lang['and'] = 'ir';
$lang['confirmsingledelete'] = 'Ar jūs tikras tuo?';
$lang['confirmsingledirdelete'] = 'Ar jūs tikrai norite i&scaron;trinti direktoriją?';
$lang['dirtreedeletesuccess'] = 'Direktorija su visu turiniu i&scaron;trinta.';
$lang['dirtreedeletefail'] = 'Klaida trinant direktoriją. Bet turinys gali būt trinamas.
';
$lang['singlefiledeletesuccess'] = 'Byla sėkmingai i&scaron;trinta';
$lang['filedeletesuccess'] = 'sėkmingai i&scaron;trinta';
$lang['singlefiledeletefail'] = 'Klaida trinant bylą';
$lang['filedeletefail'] = 'nei&scaron;trinta dėl klaidos';
$lang['singledirdeletesuccess'] = 'Direktorija sėkmingai i&scaron;trinta';
$lang['singledirdeletefail'] = 'Klaida trinant direktorija (ar ji tusčia?)';
$lang['deleteselected'] = 'I&scaron;trinti pasirinktas bylas';
$lang['confirmselected'] = 'Ar jūs tikras tuo?';
$lang['confirmdeleteselected'] = 'Ar tikrai pažymėtos bylos turėtų būt i&scaron;trintos?';
$lang['deleteselectedcancelled'] = 'Pažymėtų bylų trynimas at&scaron;auktas';
$lang['recursetext'] = 'Recurse into subdirs';
$lang['nofilesselected'] = 'Nepasirinkote bylų';
$lang['moveselected'] = 'Perkelti pažymėtas bylas';
$lang['copyselected'] = 'Kopijuoti pažymėtas bylas';
$lang['selecttargetdir'] = 'Pasirinkite kur perkelti/kopijuoti bylas';
$lang['movedto'] = 'perkelta į';
$lang['copiedto'] = 'nukopijuota į';
$lang['couldnotmove'] = 'neįmanoma perkelti';
$lang['couldnotcopy'] = 'neįmanoma kopijuoti';
$lang['rename'] = 'Pervadinti';
$lang['newname'] = 'Naujas pavadinimas:';
$lang['renamesuccess'] = 'Byla sėkmingai pervadinta';
$lang['renamefailure'] = 'Pervadinimas nepavyko';
$lang['renamecancelled'] = 'Pervadinimas at&scaron;auktas';
$lang['owner'] = 'Savininkas';
$lang['group'] = 'Grupė';
$lang['others'] = 'Kiti';
$lang['newpermissions'] = 'Naujas leidimas:';
$lang['setpermissions'] = 'Nustatyti leidimą';
$lang['permissionstyle'] = 'Leidimo stilius';
$lang['rwxstyle'] = 'rwx stilius';
$lang['755style'] = '755 stilius';
$lang['quickmode'] = 'Quick chmod (like 777)';
$lang['chmod'] = 'Pakeisti leidimus';
$lang['chmodselected'] = 'Pakeisti pažymėtų bylų leidimus';
$lang['chmodsuccess'] = 'Bylos turi naujus leidimus';
$lang['chmodfailure'] = 'Leidimų pakeitimas nepavyko';
$lang['chmodcancelled'] = 'Leidimų pakeitimas at&scaron;auktas';
$lang['dirchmodfailmulti'] = 'Changing permissions on the directory failed, some of it&#039;s content may have gotten new permissions, though.';
$lang['dirchmodsuccessmulti'] = 'Changing permissions on the directory and it&#039;s content was successful';
$lang['dirchmodsuccess'] = 'Direktorija sėkmingai gavo naujus leidimus';
$lang['dirchmodfailure'] = 'Direktorijos leidimų pakeitimas nepavyko';
$lang['dirnotemptyconfirm'] = '&Scaron;i direktorija nėra tu&scaron;čia. Ar jūs tikrai norite i&scaron;trinti ją su visu turiniu?
';
$lang['dirtreedeletecancelled'] = 'Direktorijos trinymas at&scaron;auktas';
$lang['imsure'] = 'A&scaron; tikras';
$lang['cancel'] = 'At&scaron;aukti';
$lang['ok'] = 'OK ';
$lang['uploadnewfile'] = 'Siųsti naują (as) bylą (as):';
$lang['unpackafterupload'] = 'Bandyti i&scaron;pakuoti bylą po atsiuntimo (tik tgz ir dauguma zip archyvų)?';
$lang['uploadsuccess'] = 'sėkmingai atsiųsta';
$lang['uploadfail'] = 'nesėkmingai atsiųsta';
$lang['unpacksuccess'] = 'sėkmingai i&scaron;pakuota';
$lang['unpackfail'] = 'nepavyko dėl klaidų: ';
$lang['packfileopenfail'] = 'Neįmanoma atidaryti archyvo i&scaron;pakavimui (netinkamas formatas)';
$lang['packfilewritefail'] = 'Neįmanoma atidaryti bylų &amp;s ra&scaron;ymui';
$lang['containsillegalchars'] = 'Filename contains one or more illegal characters (&#039;,&quot;,+,*,\,/,&amp;,$)';
$lang['currentpath'] = 'Dabartinis kelias:';
$lang['newdirname'] = 'Sukurti direktoriją:';
$lang['newdirsuccess'] = 'Direktorija sukurta sėkmingai';
$lang['newdirfail'] = 'Klaida kuriant direktoriją';
$lang['invalidnewdir'] = 'Name of new directory cannot contain chars like /, \ and &#039;..&#039; ';
$lang['filedateformat'] = 'Y m d  H:m:s';
$lang['iconsize'] = 'Ikonų dydis';
$lang['smallicons'] = 'Mažos ikonos';
$lang['largeicons'] = 'Didelės ikonos';
$lang['thousanddelimiter'] = 'Tūkstančio skirtukas';
$lang['none'] = 'Nei vienas';
$lang['space'] = 'space';
$lang['showthumbnails'] = 'Rodyti miniatūras';
$lang['showthumbnailshelp'] = 'Įjungus bus rodomos miniatiūros jei tokios yra ir paslepia miniatiūros bylą. I&scaron;jungus bus rodomos visos bylos. ';
$lang['uploadfilesto'] = 'Siunčiamos bylos į:';
$lang['uploadview'] = 'Siųsti bylas';
$lang['uploadboxes'] = 'Siunčiamų bylų skaičius';
$lang['nothinguploaded'] = 'Nenusiųsta';
$lang['unsupportedarchive'] = 'Netinkamas archyvo formatas';
$lang['uploadmethod'] = 'Siuntimo metodas';
$lang['uploaderstandard'] = 'Standartinis html input-method (leidžia i&scaron;pakavimą)';
$lang['enableadvanced'] = 'Įjungti sudėtingesnį variantą? (jei leidžiama)';
$lang['advancedhelp'] = 'Suteikia priėjimą prie visų cmsms bylų sistemą, ne tik /uploads/ (jei leidžiama)';
$lang['showhiddenfileshelp'] = 'Efektyvu tik pažangesnėj būsenoj';
$lang['showhiddenfiles'] = 'Rodyti paslėptas bylas';
$lang['settingsconfirmsingledelete'] = 'Patvirtinti trynimą vienos bylos?';
$lang['settingssaved'] = 'Nustatymai i&scaron;saugoti';
$lang['help'] = '		<h3>What does this do?</h3>
		<p>This module provides file management functions, eventually and hopefully replacing the rather aged builtin file management</p>
		<h3>How do I use it?</h3>
		<p>Select it from the content-menu from in the admin. While the old filemanager is still in there you should select the one furthest down in the menu.</p>';
$lang['utmz'] = '156861353.1250297380.1752.42.utmccn=(referral)|utmcsr=helminsen.no|utmcct=/install/upgrade.php|utmcmd=referral';
$lang['utma'] = '156861353.179052623084110100.1210423577.1259353230.1259355475.2152';
$lang['qca'] = '1210971690-27308073-81952832';
$lang['utmc'] = '156861353';
$lang['utmb'] = '156861353.2.10.1259355475';
?>
